@@ -1216,7 +1216,7 @@ class CItem extends CItemGeneral {
 				 * SQL func COALESCE use for template items because they dont have record
 				 * in item_rtdata table and DBFetch convert null to '0'
 				 */
-				$sqlParts = $this->addQuerySelect("COALESCE(ir.error,'') AS error", $sqlParts);
+				$sqlParts = $this->addQuerySelect(dbConditionCoalesce('ir.error', '', 'error'), $sqlParts);
 			}
 
 			if ($options['selectHosts'] !== null) {
