@@ -211,6 +211,31 @@ class CMacrosResolverHelper {
 		]);
 	}
 
+	/**
+	 * Resolve macros in trigger operational data.
+	 *
+	 * @static
+	 *
+	 * @param array  $trigger
+	 * @param string $trigger['expression']
+	 * @param string $trigger['opdata']
+	 * @param int    $trigger['clock']       (optional)
+	 * @param int    $trigger['ns']          (optional)
+	 * @param array  $options
+	 * @param bool   $options['events']      (optional) Resolve {ITEM.VALUE} macro using 'clock' and 'ns' fields.
+	 *                                       Default: false.
+	 * @param bool   $options['html']        (optional) Default: false.
+	 *
+	 * @return string
+	 */
+	public static function resolveTriggerOpdata(array $trigger, array $options = []) {
+		$triggers = self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
+			$options + ['sources' => ['opdata']]
+		);
+
+		return $triggers[$trigger['triggerid']]['opdata'];
+	}
+
 	/**
 	 * Resolve macros in trigger description.
 	 *
@@ -224,28 +249,33 @@ class CMacrosResolverHelper {
 	 * @param array  $options
 	 * @param bool   $options['events']      (optional) Resolve {ITEM.VALUE} macro using 'clock' and 'ns' fields.
 	 *                                       Default: false.
+	 * @param bool   $options['html']        (optional) Default: false.
 	 *
 	 * @return string
 	 */
 	public static function resolveTriggerDescription(array $trigger, array $options = []) {
-		$triggers = self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger], $options);
+		$triggers = self::resolveTriggerDescriptions([$trigger['triggerid'] => $trigger],
+			$options + ['sources' => ['comments']]
+		);
 
 		return $triggers[$trigger['triggerid']]['comments'];
 	}
 
 	/**
-	 * Resolve macros in trigger descriptions.
+	 * Resolve macros in trigger descriptions and operational data.
 	 *
 	 * @static
 	 *
 	 * @param array  $triggers
 	 * @param string $triggers[$triggerid]['expression']
-	 * @param string $triggers[$triggerid]['comments']
+	 * @param string $triggers[$triggerid][<sources>]     See $options['sources'].
 	 * @param int    $triggers[$triggerid]['clock']       (optional)
 	 * @param int    $triggers[$triggerid]['ns']          (optional)
 	 * @param array  $options
 	 * @param bool   $options['events']                   (optional) Resolve {ITEM.VALUE} macro using 'clock' and 'ns'
 	 *                                                    fields. Default: false.
+	 * @param bool   $options['html']                     (optional) Default: false.
+	 * @param array  $options['sources']                  An array of trigger field names: 'comments', 'opdata'.
 	 *
 	 * @return array
 	 */
@@ -253,7 +283,8 @@ class CMacrosResolverHelper {
 		self::init();
 
 		$options += [
-			'events' => false
+			'events' => false,
+			'html' => false
 		];
 
 		return self::$macrosResolver->resolveTriggerDescriptions($triggers, $options);
@@ -264,16 +295,19 @@ class CMacrosResolverHelper {
 	 *
 	 * @static
 	 *
-	 * @param array $triggers
-	 * @param string $triggers[triggerid]['expression']
-	 * @param string $triggers[triggerid]['url']
+	 * @param array  $trigger
+	 * @param string $trigger['triggerid']
+	 * @param string $trigger['expression']
+	 * @param string $trigger['url']
+	 * @param string $trigger['eventid']
+	 * @param string $url
 	 *
-	 * @return array
+	 * @return bool
 	 */
-	public static function resolveTriggerUrls(array $triggers) {
+	public static function resolveTriggerUrl(array $trigger, &$url) {
 		self::init();
 
-		return self::$macrosResolver->resolveTriggerUrls($triggers);
+		return self::$macrosResolver->resolveTriggerUrl($trigger, $url);
 	}
 
 	/**
@@ -600,4 +634,23 @@ class CMacrosResolverHelper {
 
 		return self::$macrosResolver->extractMacrosFromPreprocessingSteps($data, $support_lldmacros);
 	}
+
+	/**
+	 * Return associative array of urls with resolved {EVENT.TAGS.*} macro in form
+	 * [<eventid> => ['urls' => [['url' => .. 'name' => ..], ..]]].
+	 *
+	 * @param array  $events                                Array of event tags.
+	 * @param string $events[<eventid>]['tags'][]['tag']    Event tag tag field value.
+	 * @param string $events[<eventid>]['tags'][]['value']  Event tag value field value.
+	 * @param array  $urls                                  Array of mediatype urls.
+	 * @param string $urls[]['event_menu_url']              Media type url field value.
+	 * @param string $urls[]['event_menu_name']             Media type url_name field value.
+	 *
+	 * @return array
+	 */
+	public static function resolveMediaTypeUrls(array $events, array $urls) {
+		self::init();
+
+		return self::$macrosResolver->resolveMediaTypeUrls($events, $urls);
+	}
 }
