@@ -25,7 +25,7 @@ if ($data['hostid'] != 0) {
 	$widget->addItem(get_header_host_table('items', $data['hostid']));
 }
 
-// create form
+// Create form.
 $form = (new CForm())
 	->setName('itemForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
@@ -33,8 +33,8 @@ $form = (new CForm())
 	->addVar('hostid', $data['hostid'])
 	->addVar('action', $data['action']);
 
-// Create form list.
-$form_list = (new CFormList('itemFormList'))
+// Create item form list.
+$item_form_list = (new CFormList('item-form-list'))
 	// Append type to form list.
 	->addRow(
 		(new CVisibilityBox('visible[type]', 'type', _('Original')))
@@ -44,10 +44,10 @@ $form_list = (new CFormList('itemFormList'))
 		new CComboBox('type', $data['type'], null, $data['itemTypes'])
 	);
 
-// Append hosts to form list.
+// Append hosts to item form list.
 if ($data['displayInterfaces']) {
-	$interfacesComboBox = new CComboBox('interfaceid', $data['interfaceid']);
-	$interfacesComboBox->addItem(new CComboItem(0, '', false, false));
+	$interfaces_combo_box = new CComboBox('interfaceid', $data['interfaceid']);
+	$interfaces_combo_box->addItem(new CComboItem(0, '', false, false));
 
 	// Set up interface groups sorted by priority.
 	$interface_types = zbx_objectValues($data['hosts']['interfaces'], 'type');
@@ -71,7 +71,7 @@ if ($data['displayInterfaces']) {
 		$interface_groups[$interface['type']]->addItem($option);
 	}
 	foreach ($interface_groups as $interface_group) {
-		$interfacesComboBox->addItem($interface_group);
+		$interfaces_combo_box->addItem($interface_group);
 	}
 
 	$span = (new CSpan(_('No interface found')))
@@ -79,19 +79,19 @@ if ($data['displayInterfaces']) {
 		->setId('interface_not_defined')
 		->setAttribute('style', 'display: none;');
 
-	$form_list->addRow(
+	$item_form_list->addRow(
 		(new CVisibilityBox('visible[interfaceid]', 'interfaceDiv', _('Original')))
 			->setLabel(_('Host interface'))
 			->setChecked(isset($data['visible']['interfaceid']))
 			->setAttribute('data-multiple-interface-types', $data['multiple_interface_types']),
-		(new CDiv([$interfacesComboBox, $span]))->setId('interfaceDiv'),
+		(new CDiv([$interfaces_combo_box, $span]))->setId('interfaceDiv'),
 		'interface_row'
 	);
 	$form->addVar('selectedInterfaceId', $data['interfaceid']);
 }
 
-$form_list
-	// Append jmx endpoint to form list.
+$item_form_list
+	// Append jmx endpoint to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[jmx_endpoint]', 'jmx_endpoint', _('Original')))
 			->setLabel(_('JMX endpoint'))
@@ -141,7 +141,7 @@ else {
 $headers = (new CTag('script', true))->setAttribute('type', 'text/json');
 $headers->items = [CJs::encodeJson($headers_data)];
 
-$form_list
+$item_form_list
 	->addRow(
 		(new CVisibilityBox('visible[headers]', 'headers_pairs', _('Original')))
 			->setLabel(_('Headers'))
@@ -162,9 +162,10 @@ $form_list
 				->setAttribute('type', 'text/x-jquery-tmpl')
 				->addItem(new CRow([
 					(new CCol((new CDiv)->addClass(ZBX_STYLE_DRAG_ICON)))->addClass(ZBX_STYLE_TD_DRAG_ICON),
-					(new CTextBox('headers[name][#{index}]', '#{name}'))->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+					(new CTextBox('headers[name][#{index}]', '#{name}'))->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
 					'&rArr;',
-					(new CTextBox('headers[value][#{index}]', '#{value}'))->setWidth(ZBX_TEXTAREA_TAG_WIDTH),
+					(new CTextBox('headers[value][#{index}]', '#{value}', false, 2000))
+						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
 					(new CButton(null, _('Remove')))
 						->addClass(ZBX_STYLE_BTN_LINK)
 						->setAttribute('data-row-action', 'remove_row')
@@ -176,28 +177,28 @@ $form_list
 			->setAttribute('data-sortable-pairs-table', '1')
 			->setAttribute('style', 'min-width: '.ZBX_TEXTAREA_BIG_WIDTH.'px;')
 	)
-	// Append SNMP community to form list.
+	// Append SNMP community to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmp_community]', 'snmp_community', _('Original')))
 			->setLabel(_('SNMP community'))
 			->setChecked(isset($data['visible']['snmp_community'])),
 		(new CTextBox('snmp_community', $data['snmp_community']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append SNMPv3 contextname to form list.
+	// Append SNMPv3 contextname to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_contextname]', 'snmpv3_contextname', _('Original')))
 			->setLabel(_('Context name'))
 			->setChecked(isset($data['visible']['snmpv3_contextname'])),
 		(new CTextBox('snmpv3_contextname', $data['snmpv3_contextname']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append SNMPv3 securityname to form list.
+	// Append SNMPv3 securityname to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_securityname]', 'snmpv3_securityname', _('Original')))
 			->setLabel(_('Security name'))
 			->setChecked(isset($data['visible']['snmpv3_securityname'])),
 		(new CTextBox('snmpv3_securityname', $data['snmpv3_securityname']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append SNMPv3 securitylevel to form list.
+	// Append SNMPv3 securitylevel to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_securitylevel]', 'snmpv3_securitylevel', _('Original')))
 			->setLabel(_('Security level'))
@@ -208,7 +209,7 @@ $form_list
 			ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV => 'authPriv'
 		])
 	)
-	// Append SNMPv3 authprotocol to form list.
+	// Append SNMPv3 authprotocol to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_authprotocol]', 'authprotocol_div', _('Original')))
 			->setLabel(_('Authentication protocol'))
@@ -220,7 +221,7 @@ $form_list
 				->setModern(true)
 		))->setId('authprotocol_div')
 	)
-	// Append SNMPv3 authpassphrase to form list.
+	// Append SNMPv3 authpassphrase to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_authpassphrase]', 'snmpv3_authpassphrase', _('Original')))
 			->setLabel(_('Authentication passphrase'))
@@ -228,7 +229,7 @@ $form_list
 		(new CTextBox('snmpv3_authpassphrase', $data['snmpv3_authpassphrase']))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append SNMPv3 privprotocol to form list.
+	// Append SNMPv3 privprotocol to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_privprotocol]', 'privprotocol_div', _('Original')))
 			->setLabel(_('Privacy protocol'))
@@ -241,7 +242,7 @@ $form_list
 		))
 			->setId('privprotocol_div')
 	)
-	// Append SNMPv3 privpassphrase to form list.
+	// Append SNMPv3 privpassphrase to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[snmpv3_privpassphrase]', 'snmpv3_privpassphrase', _('Original')))
 			->setLabel(_('Privacy passphrase'))
@@ -249,14 +250,14 @@ $form_list
 		(new CTextBox('snmpv3_privpassphrase', $data['snmpv3_privpassphrase']))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append port to form list.
+	// Append port to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[port]', 'port', _('Original')))
 			->setLabel(_('Port'))
 			->setChecked(isset($data['visible']['port'])),
 		(new CTextBox('port', $data['port']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 	)
-	// Append value type to form list.
+	// Append value type to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[value_type]', 'value_type', _('Original')))
 			->setLabel(_('Type of information'))
@@ -269,14 +270,14 @@ $form_list
 			ITEM_VALUE_TYPE_TEXT => _('Text')
 		])
 	)
-	// Append units to form list.
+	// Append units to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[units]', 'units', _('Original')))
 			->setLabel(_('Units'))
 			->setChecked(isset($data['visible']['units'])),
 		(new CTextBox('units', $data['units']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	)
-	// Append authtype to form list.
+	// Append authtype to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[authtype]', 'authtype', _('Original')))
 			->setLabel(_('Authentication method'))
@@ -286,35 +287,38 @@ $form_list
 			ITEM_AUTHTYPE_PUBLICKEY => _('Public key')
 		])
 	)
-	// Append username to form list.
+	// Append username to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[username]', 'username', _('Original')))
 			->setLabel(_('User name'))
 			->setChecked(isset($data['visible']['username'])),
 		(new CTextBox('username', $data['username']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 	)
-	// Append publickey to form list.
+	// Append publickey to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[publickey]', 'publickey', _('Original')))
 			->setLabel(_('Public key file'))
 			->setChecked(isset($data['visible']['publickey'])),
 		(new CTextBox('publickey', $data['publickey']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 	)
-	// Append privatekey to form list.
+	// Append privatekey to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[privatekey]', 'privatekey', _('Original')))
 			->setLabel(_('Private key file'))
 			->setChecked(isset($data['visible']['privatekey'])),
 		(new CTextBox('privatekey', $data['privatekey']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 	)
-	// Append password to form list.
+	// Append password to item form list.
 	->addRow(
 		(new CVisibilityBox('visible[password]', 'password', _('Original')))
 			->setLabel(_('Password'))
 			->setChecked(isset($data['visible']['password'])),
 		(new CTextBox('password', $data['password']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
-	)
-	// Append item pre-processing to form list.
+	);
+
+// Create preprocessing form list.
+$preprocessing_form_list = (new CFormList('preprocessing-form-list'))
+	// Append item pre-processing to preprocessing form list.
 	->addRow(
 		(new CVisibilityBox('visible[preprocessing]', 'preprocessing_div', _('Original')))
 			->setLabel(_('Preprocessing steps'))
@@ -385,7 +389,7 @@ $update_interval->addRow(
 	]))
 );
 
-$form_list
+$item_form_list
 	// Append delay to form list.
 	->addRow(
 		(new CVisibilityBox('visible[delay]', 'update_interval_div', _('Original')))
@@ -395,30 +399,52 @@ $form_list
 	)
 	// Append history to form list.
 	->addRow(
-		(new CVisibilityBox('visible[history]', 'history', _('Original')))
+		(new CVisibilityBox('visible[history]', 'history_div', _('Original')))
 			->setLabel(_('History storage period'))
 			->setChecked(isset($data['visible']['history'])),
-		(new CTextBox('history', $data['history']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		(new CDiv([
+			(new CRadioButtonList('history_mode', (int) $data['history_mode']))
+				->addValue(_('Do not keep history'), ITEM_STORAGE_OFF)
+				->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
+				->setModern(true),
+			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+			(new CTextBox('history', $data['history']))
+				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+				->setAriaRequired()
+		]))
+			->addClass('wrap-multiple-controls')
+			->setId('history_div')
 	)
 	// Append trends to form list.
 	->addRow(
-		(new CVisibilityBox('visible[trends]', 'trends', _('Original')))
+		(new CVisibilityBox('visible[trends]', 'trends_div', _('Original')))
 			->setLabel(_('Trend storage period'))
 			->setChecked(isset($data['visible']['trends'])),
-		(new CTextBox('trends', $data['trends']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		(new CDiv([
+			(new CRadioButtonList('trends_mode', (int) $data['trends_mode']))
+				->addValue(_('Do not keep trends'), ITEM_STORAGE_OFF)
+				->addValue(_('Storage period'), ITEM_STORAGE_CUSTOM)
+				->setModern(true),
+			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+			(new CTextBox('trends', $data['trends']))
+				->setWidth(ZBX_TEXTAREA_TINY_WIDTH)
+				->setAriaRequired()
+		]))
+			->addClass('wrap-multiple-controls')
+			->setId('trends_div')
 	);
 
 // Append status to form list.
-$statusComboBox = new CComboBox('status', $data['status']);
+$status_combo_box = new CComboBox('status', $data['status']);
 foreach ([ITEM_STATUS_ACTIVE, ITEM_STATUS_DISABLED] as $status) {
-	$statusComboBox->addItem($status, item_status2str($status));
+	$status_combo_box->addItem($status, item_status2str($status));
 }
-$form_list
+$item_form_list
 	->addRow(
 		(new CVisibilityBox('visible[status]', 'status', _('Original')))
 			->setLabel(_('Status'))
 			->setChecked(isset($data['visible']['status'])),
-		$statusComboBox
+		$status_combo_box
 	)
 	// Append logtime to form list.
 	->addRow(
@@ -429,18 +455,18 @@ $form_list
 	);
 
 // Append valuemap to form list.
-$valueMapsComboBox = new CComboBox('valuemapid', $data['valuemapid']);
-$valueMapsComboBox->addItem(0, _('As is'));
+$value_maps_combo_box = new CComboBox('valuemapid', $data['valuemapid']);
+$value_maps_combo_box->addItem(0, _('As is'));
 foreach ($data['valuemaps'] as $valuemap) {
-	$valueMapsComboBox->addItem($valuemap['valuemapid'], $valuemap['name']);
+	$value_maps_combo_box->addItem($valuemap['valuemapid'], $valuemap['name']);
 }
 
-$form_list
+$item_form_list
 	->addRow(
 		(new CVisibilityBox('visible[valuemapid]', 'valuemap', _('Original')))
 			->setLabel(_('Show value'))
 			->setChecked(isset($data['visible']['valuemapid'])),
-		(new CDiv([$valueMapsComboBox, SPACE,
+		(new CDiv([$value_maps_combo_box, SPACE,
 			(new CLink(_('show value mappings'), 'adm.valuemapping.php'))->setAttribute('target', '_blank')
 		]))->setId('valuemap')
 	)
@@ -512,7 +538,7 @@ if ($data['displayApplications']) {
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
 		->setId('applications_div');
 
-	$form_list->addRow(
+	$item_form_list->addRow(
 		(new CVisibilityBox('visible[applications]', 'applications_div', _('Original')))
 			->setLabel(_('Applications'))
 			->setChecked(array_key_exists('applications', $data['visible'])),
@@ -552,7 +578,7 @@ if ($data['displayMasteritems']) {
 			->setAriaRequired(true)
 	]))->setId('master_item');
 
-	$form_list->addRow(
+	$item_form_list->addRow(
 		(new CVisibilityBox('visible[master_itemid]', 'master_item', _('Original')))
 			->setLabel(_('Master item'))
 			->setChecked(array_key_exists('master_itemid', $data['visible'])),
@@ -561,22 +587,28 @@ if ($data['displayMasteritems']) {
 }
 
 // Append description to form list.
-$form_list->addRow(
+$item_form_list->addRow(
 	(new CVisibilityBox('visible[description]', 'description', _('Original')))
 		->setLabel(_('Description'))
 		->setChecked(isset($data['visible']['description'])),
 	(new CTextArea('description', $data['description']))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 );
 
+$tabs = (new CTabView())
+	->addTab('itemTab', _('Item'), $item_form_list)
+	->addTab('preprocessingTab', _('Preprocessing'), $preprocessing_form_list)
+	->setFooter(makeFormFooter(
+		new CSubmit('massupdate', _('Update')),
+		[new CButtonCancel(url_param('hostid'))]
+	));
+
+if (!hasRequest('massupdate')) {
+	$tabs->setSelected(0);
+}
+
 // Append tabs to form.
-$form->addItem(
-	(new CTabView())
-		->addTab('itemTab', _('Mass update'), $form_list)
-		->setFooter(makeFormFooter(
-			new CSubmit('massupdate', _('Update')),
-			[new CButtonCancel(url_param('hostid'))]
-		))
-);
+$form->addItem($tabs);
+
 $widget->addItem($form);
 
 require_once dirname(__FILE__).'/js/configuration.item.massupdate.js.php';
