@@ -502,13 +502,13 @@ function overlayDialogueDestroy(dialogueid, xhr) {
 
 		jQuery('[data-dialogueid='+dialogueid+']').remove();
 
-		if (!jQuery('[data-dialogueid]').length) {
-			jQuery('body').css({'overflow': ''});
-			jQuery('body[style=""]').removeAttr('style');
-		}
-
 		removeFromOverlaysStack(dialogueid);
 		jQuery.publish('overlay.close', {dialogueid: dialogueid});
+
+		if (!jQuery('[data-dialogueid]').length) {
+			jQuery('body').css('overflow', jQuery('body').data('overflow'));
+			jQuery('body').removeData('overflow');
+		}
 	}
 }
 
@@ -553,6 +553,11 @@ function getOverlayDialogueId() {
  * @return {bool}
  */
 function overlayDialogue(params, trigger_elmnt, xhr) {
+	if (!jQuery('[data-dialogueid]').length) {
+		jQuery('body').data('overflow', jQuery('body').css('overflow'));
+		jQuery('body').css('overflow', 'hidden');
+	}
+
 	var button_focused = null,
 		cancel_action = null,
 		submit_btn = null,
@@ -731,8 +736,6 @@ function overlayDialogue(params, trigger_elmnt, xhr) {
 		}
 	});
 
-	jQuery('body').css({'overflow': 'hidden'});
-
 	if (button_focused !== null) {
 		button_focused.focus();
 	}
@@ -874,7 +877,15 @@ function executeScript(hostid, scriptid, confirmation, trigger_elmnt) {
 						l = n['name'].indexOf('[', r + 1);
 						r = n['name'].indexOf(']', r + 1);
 
-						if (l == -1 || r == -1 || r <= l) {
+						if (l + 1 == r) {
+							if (typeof curr_json[key] === 'undefined') {
+								curr_json[key] = [];
+							}
+
+							curr_json[key].push(n['value']);
+							break;
+						}
+						else if (l == -1 || r == -1 || r <= l) {
 							curr_json[key] = n['value']
 							break;
 						}
