@@ -130,52 +130,6 @@ var MMenu = {
 				});
 			}
 		});
-
-		if (SF) {
-			var nav_elems = jQuery('.top-subnav a, .search, .btn-search, .top-nav-zbbshare, .top-nav-help, .top-nav-profile, .top-nav-signout')
-					.on('keydown', function(event) {
-				if (event.which == 9) {
-					var visible_subnav_elems = nav_elems.filter(function() {
-						return jQuery(this).is(':visible');
-					});
-					var current = visible_subnav_elems.toArray().indexOf(this);
-
-					if (event.shiftKey && current > 0) {
-						visible_subnav_elems.get(current - 1).focus();
-					}
-					else if (!event.shiftKey && visible_subnav_elems.length > current + 1) {
-						visible_subnav_elems.get(current + 1).focus();
-					}
-					else if (event.shiftKey && current == 0) {
-						// Find the previous :focusable element to focus.
-						var active_element_index = jQuery('*', 'body').toArray().indexOf(document.activeElement),
-							prev_element = null;
-
-						jQuery('*', 'body').each(function(i) {
-							if (active_element_index > i && jQuery(this).is(':focusable')) {
-								prev_element = this;
-							};
-						});
-
-						if (prev_element) {
-							prev_element.focus();
-						}
-					}
-					else if (current + 1 == visible_subnav_elems.length) {
-						// If this is the last item in the sub-menu list, focus next :focusable element.
-						var active_element_index = jQuery('*', 'body').toArray().indexOf(document.activeElement);
-
-						jQuery('*', 'body').filter(function(i) {
-							return (i > active_element_index && jQuery(this).is(':focusable'));
-						}).get(0).focus();
-					}
-
-					event.preventDefault();
-
-					return false;
-				}
-			});
-		}
 	},
 
 	mouseOver: function(show_label) {
@@ -883,12 +837,13 @@ function getConditionFormula(conditions, evalType) {
 	 * Creates a table with dynamic add/remove row buttons.
 	 *
 	 * Supported options:
-	 * - template		- row template selector
-	 * - row			- element row selector
-	 * - add			- add row button selector
-	 * - remove			- remove row button selector
-	 * - counter 		- number to start row enumeration from
-	 * - dataCallback	- function to generate the data passed to the template
+	 * - template				- row template selector
+	 * - row					- element row selector
+	 * - add					- add row button selector
+	 * - remove					- remove row button selector
+	 * - counter 				- number to start row enumeration from
+	 * - dataCallback			- function to generate the data passed to the template
+	 * - remove_next_sibling	- remove also next element
 	 *
 	 * Triggered events:
 	 * - tableupdate.dynamicRows 	- after adding or removing a row.
@@ -904,6 +859,7 @@ function getConditionFormula(conditions, evalType) {
 			row: '.form_row',
 			add: '.element-table-add',
 			remove: '.element-table-remove',
+			remove_next_sibling: false,
 			disable: '.element-table-disable',
 			counter: null,
 			beforeRow: null,
@@ -974,6 +930,9 @@ function getConditionFormula(conditions, evalType) {
 	 * @param {object} options
 	 */
 	function removeRow(table, row, options) {
+		if (options.remove_next_sibling) {
+			row.next().remove();
+		}
 		row.remove();
 
 		table.trigger('tableupdate.dynamicRows', options);
@@ -1067,82 +1026,3 @@ jQuery(function ($) {
 		$(window).scrollTop(sessionStorage.scrollTop);
 	}
 });
-
-
-jQuery(function ($) {
-	"use strict";
-
-	function calcRows($obj, options) {
-		var max_height = (options && 'maxHeight' in options) ? options.maxHeight : null,
-			clone = $obj
-				.clone(false)
-				.css({'position': 'absolute', 'z-index': '-1'})
-				.removeClass('patternselect')
-				.insertAfter($obj),
-			padding = parseInt(clone.css('padding-top'), 10) + parseInt(clone.css('padding-bottom'), 10),
-			line_height = parseInt(clone.css('font-size'), 10) * 1.14,
-			rows = 0;
-
-		do {
-			rows++;
-			clone.height(rows * line_height);
-		}
-		while (clone[0].scrollHeight - padding > clone.innerHeight()
-			&& (max_height === null || rows * line_height + padding <= max_height));
-		clone.remove();
-
-		return rows;
-	}
-
-	var methods = {
-		init: function(options) {
-			options = $.extend({}, options);
-
-			this.each(function() {
-				if (typeof $(this).data('autogrow') === 'undefined') {
-					$(this)
-						.css({
-							'resize': 'none',
-							'overflow-x': 'hidden',
-							'white-space': 'pre-line'
-						})
-						.on('paste change keyup', function() {
-							var rows = calcRows($(this), options);
-
-							if (options && 'pair' in options) {
-								var pair_rows = calcRows($(options.pair), options);
-								if (pair_rows > rows) {
-									rows = pair_rows;
-								}
-								$(options.pair).attr('rows', rows);
-							}
-
-							$(this).attr('rows', rows);
-						})
-						.data('autogrow', options)
-						.trigger('keyup');
-				}
-
-				if ($(this).prop('maxlength') !== 'undefined' && !CR && !GK) {
-					$(this).bind('paste contextmenu change keydown keypress keyup', function() {
-						if ($(this).val().length > $(this).attr('maxlength')) {
-							$(this).val($(this).val().substr(0, $(this).attr('maxlength')));
-						}
-					});
-				}
-
-				if (options && 'pair' in options) {
-					$(options.pair).css({'resize': 'none'});
-				}
-			});
-		}
-	};
-
-	$.fn.autoGrowTextarea = function(method, options) {
-		if (methods[method]) {
-			return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
-		}
-
-		return methods.init.apply(this, arguments);
-	};
-});
